betty.test_utils.copyright_notice module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.copyright_notice module

Test utilities for `betty.copyright_notice`.

class betty.test_utils.copyright_notice.CopyrightNoticeTestBase

  Bases: `PluginInstanceTestBase`[`CopyrightNotice`]

  A base class for testing `betty.copyright_notice.CopyrightNotice` implementations.

  test_summary() → None

    Tests `betty.copyright_notice.CopyrightNotice.summary()` implementations.

  test_text() → None

    Tests `betty.copyright_notice.CopyrightNotice.text()` implementations.

  test_url() → None

    Tests `betty.copyright_notice.CopyrightNotice.url()` implementations.

class betty.test_utils.copyright_notice.DummyCopyrightNotice

  Bases: `DummyPlugin`, `CopyrightNotice`

  A dummy copyright notice implementation.

  property summary: Localizable

    The copyright summary.

  property text: Localizable

    The full copyright text.